==> 2.0.1.tar.gz: lib/src/client/models/image.dart <==
class GiphyFullImage {
  final String url;
  final String width;
  final String height;
  final String size;
  final String mp4;
  final String mp4Size;
  final String webp;
  final String webpSize;

  GiphyFullImage({
    required this.url,
    required this.width,
    required this.height,
    required this.size,
    required this.mp4,
    required this.mp4Size,
    required this.webp,
    required this.webpSize,
  });

  factory GiphyFullImage.fromJson(Map<String, dynamic> json) => GiphyFullImage(
      url: json['url'],
      width: json['width'],
      height: json['height'],
      size: json['size'],
      mp4: json['mp4'],
      mp4Size: json['mp4_size'],
      webp: json['webp'],
      webpSize: json['webp_size']);

  Map<String, dynamic> toJson() {
    return <String, dynamic>{
      'url': url,
      'width': width,
      'height': height,
      'size': size,
      'mp4': mp4,
      'mp4_size': mp4Size,
      'webp': webp,
      'webp_size': webpSize
    };
  }

  @override
  String toString() {
    return 'GiphyFullImage{url: $url, width: $width, height: $height, size: $size, mp4: $mp4, mp4Size: $mp4Size, webp: $webp, webpSize: $webpSize}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is GiphyFullImage &&
          runtimeType == other.runtimeType &&
          url == other.url &&
          width == other.width &&
          height == other.height &&
          size == other.size &&
          mp4 == other.mp4 &&
          mp4Size == other.mp4Size &&
          webp == other.webp &&
          webpSize == other.webpSize;

  @override
  int get hashCode =>
      url.hashCode ^
      width.hashCode ^
      height.hashCode ^
      size.hashCode ^
      mp4.hashCode ^
      mp4Size.hashCode ^
      webp.hashCode ^
      webpSize.hashCode;
}

class GiphyOriginalImage {
  final String url;
  final String width;
  final String height;
  final String size;
  final String frames;
  final String mp4;
  final String mp4Size;
  final String webp;
  final String webpSize;
  final String hash;

  GiphyOriginalImage({
    required this.url,
    required this.width,
    required this.height,
    required this.size,
    required this.frames,
    required this.mp4,
    required this.mp4Size,
    required this.webp,
    required this.webpSize,
    required this.hash,
  });

  factory GiphyOriginalImage.fromJson(Map<String, dynamic> json) {
    return GiphyOriginalImage(
        url: json['url'],
        width: json['width'],
        height: json['height'],
        size: json['size'],
        frames: json['frames'],
        mp4: json['mp4'],
        mp4Size: json['mp4_size'],
        webp: json['webp'],
        webpSize: json['webp_size'],
        hash: json['hash']);
  }

  Map<String, dynamic> toJson() {
    return <String, dynamic>{
      'url': url,
      'width': width,
      'height': height,
      'size': size,
      'frames': frames,
      'mp4': mp4,
      'mp4_size': mp4Size,
      'webp': webp,
      'webp_size': webpSize,
      'hash': hash
    };
  }

  @override
  String toString() {
    return 'GiphyOriginalImage{url: $url, width: $width, height: $height, size: $size, frames: $frames, mp4: $mp4, mp4Size: $mp4Size, webp: $webp, webpSize: $webpSize, hash: $hash}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is GiphyOriginalImage &&
          runtimeType == other.runtimeType &&
          url == other.url &&
          width == other.width &&
          height == other.height &&
          size == other.size &&
          frames == other.frames &&
          mp4 == other.mp4 &&
          mp4Size == other.mp4Size &&
          webp == other.webp &&
          webpSize == other.webpSize &&
          hash == other.hash;

  @override
  int get hashCode =>
      url.hashCode ^
      width.hashCode ^
      height.hashCode ^
      size.hashCode ^
      frames.hashCode ^
      mp4.hashCode ^
      mp4Size.hashCode ^
      webp.hashCode ^
      webpSize.hashCode ^
      hash.hashCode;
}

class GiphyStillImage {
  final String url;
  final String width;
  final String height;
  final String size;

  GiphyStillImage({
    required this.url,
    required this.width,
    required this.height,
    required this.size,
  });

  factory GiphyStillImage.fromJson(Map<String, dynamic?> json) =>
      GiphyStillImage(
          url: json['url'],
          width: json['width'],
          height: json['height'],
          size: json['size'] ?? '');

  Map<String, dynamic> toJson() {
    return <String, dynamic>{
      'url': url,
      'width': width,
      'height': height,
      'size': size
    };
  }

  @override
  String toString() {
    return 'GiphyStillImage{url: $url, width: $width, height: $height, size: $size}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is GiphyStillImage &&
          runtimeType == other.runtimeType &&
          url == other.url &&
          width == other.width &&
          height == other.height &&
          size == other.size;

  @override
  int get hashCode =>
      url.hashCode ^ width.hashCode ^ height.hashCode ^ size.hashCode;
}

class GiphyDownsampledImage {
  final String url;
  final String width;
  final String height;
  final String size;
  final String webp;
  final String webpSize;

  GiphyDownsampledImage({
    required this.url,
    required this.width,
    required this.height,
    required this.size,
    required this.webp,
    required this.webpSize,
  });

  factory GiphyDownsampledImage.fromJson(Map<String, dynamic> json) {
    return GiphyDownsampledImage(
        url: json['url'],
        width: json['width'],
        height: json['height'],
        size: json['size'],
        webp: json['webp'],
        webpSize: json['webp_size']);
  }

  Map<String, dynamic> toJson() {
    return <String, dynamic>{
      'url': url,
      'width': width,
      'height': height,
      'size': size,
      'webp': webp,
      'webp_size': webpSize
    };
  }

  @override
  String toString() {
    return 'GiphyDownsampledImage{url: $url, width: $width, height: $height, size: $size, webp: $webp, webpSize: $webpSize}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is GiphyDownsampledImage &&
          runtimeType == other.runtimeType &&
          url == other.url &&
          width == other.width &&
          height == other.height &&
          size == other.size &&
          webp == other.webp &&
          webpSize == other.webpSize;

  @override
  int get hashCode =>
      url.hashCode ^
      width.hashCode ^
      height.hashCode ^
      size.hashCode ^
      webp.hashCode ^
      webpSize.hashCode;
}

class GiphyLoopingImage {
  final String mp4;
  final String mp4Size;

  GiphyLoopingImage({
    required this.mp4,
    required this.mp4Size,
  });

  factory GiphyLoopingImage.fromJson(Map<String, dynamic> json) =>
      GiphyLoopingImage(mp4: json['mp4'], mp4Size: json['mp4_size']);

  Map<String, dynamic> toJson() =>
      <String, dynamic>{'mp4': mp4, 'mp4_size': mp4Size};

  @override
  String toString() {
    return 'GiphyLoopingImage{mp4: $mp4, mp4Size: $mp4Size}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is GiphyLoopingImage &&
          runtimeType == other.runtimeType &&
          mp4 == other.mp4 &&
          mp4Size == other.mp4Size;

  @override
  int get hashCode => mp4.hashCode ^ mp4Size.hashCode;
}

class GiphyPreviewImage {
  final String width;
  final String height;
  final String mp4;
  final String mp4Size;

  GiphyPreviewImage({
    required this.width,
    required this.height,
    required this.mp4,
    required this.mp4Size,
  });

  factory GiphyPreviewImage.fromJson(Map<String, dynamic?> json) {
    return GiphyPreviewImage(
      width: json['width'],
      height: json['height'],
      mp4: json['mp4'] ?? '',
      mp4Size: json['mp4_size'] ?? '',
    );
  }

  Map<String, dynamic> toJson() {
    return <String, dynamic>{
      'width': width,
      'height': height,
      'mp4': mp4,
      'mp4_size': mp4Size
    };
  }

  @override
  String toString() {
    return 'GiphyPreviewImage{width: $width, height: $height, mp4: $mp4, mp4Size: $mp4Size}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is GiphyPreviewImage &&
          runtimeType == other.runtimeType &&
          width == other.width &&
          height == other.height &&
          mp4 == other.mp4 &&
          mp4Size == other.mp4Size;

  @override
  int get hashCode =>
      width.hashCode ^ height.hashCode ^ mp4.hashCode ^ mp4Size.hashCode;
}

class GiphyDownsizedImage {
  final String url;
  final String width;
  final String height;
  final String size;

  GiphyDownsizedImage({
    required this.url,
    required this.width,
    required this.height,
    required this.size,
  });

  factory GiphyDownsizedImage.fromJson(Map<String, dynamic> json) {
    return GiphyDownsizedImage(
      url: json['url'],
      width: json['width'],
      height: json['height'],
      size: json['size'],
    );
  }

  Map<String, dynamic> toJson() {
    return <String, dynamic>{
      'url': url,
      'width': width,
      'height': height,
      'size': size
    };
  }

  @override
  String toString() {
    return 'GiphyDownsizedImage{url: $url, width: $width, height: $height, size: $size}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is GiphyDownsizedImage &&
          runtimeType == other.runtimeType &&
          url == other.url &&
          width == other.width &&
          height == other.height &&
          size == other.size;

  @override
  int get hashCode =>
      url.hashCode ^ width.hashCode ^ height.hashCode ^ size.hashCode;
}

class GiphyWebPImage {
  final String url;
  final String width;
  final String height;
  final String size;

  GiphyWebPImage({
    required this.url,
    required this.width,
    required this.height,
    required this.size,
  });

  factory GiphyWebPImage.fromJson(Map<String, dynamic> json) {
    return GiphyWebPImage(
      url: json['url'],
      width: json['width'],
      height: json['height'],
      size: json['size'],
    );
  }

  Map<String, dynamic> toJson() {
    return <String, dynamic>{
      'url': url,
      'width': width,
      'height': height,
      'size': size
    };
  }

  @override
  String toString() {
    return 'GiphyWebPImage{url: $url, width: $width, height: $height, size: $size}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is GiphyWebPImage &&
          runtimeType == other.runtimeType &&
          url == other.url &&
          width == other.width &&
          height == other.height &&
          size == other.size;

  @override
  int get hashCode =>
      url.hashCode ^ width.hashCode ^ height.hashCode ^ size.hashCode;
}

==> 3.0.3.tar.gz: lib/src/client/models/image.dart <==
class GiphyFullImage {
  final String url;
  final String width;
  final String height;
  final String size;
  final String? mp4;
  final String? mp4Size;
  final String? webp;
  final String? webpSize;

  GiphyFullImage({
    required this.url,
    required this.width,
    required this.height,
    required this.size,
    required this.mp4,
    required this.mp4Size,
    required this.webp,
    required this.webpSize,
  });

  factory GiphyFullImage.fromJson(Map<String, dynamic> json) => GiphyFullImage(
      url: json['url'],
      width: json['width'],
      height: json['height'],
      size: json['size'],
      mp4: json['mp4'],
      mp4Size: json['mp4_size'],
      webp: json['webp'],
      webpSize: json['webp_size']);

  Map<String, dynamic> toJson() {
    return <String, dynamic>{
      'url': url,
      'width': width,
      'height': height,
      'size': size,
      'mp4': mp4,
      'mp4_size': mp4Size,
      'webp': webp,
      'webp_size': webpSize
    };
  }

  @override
  String toString() {
    return 'GiphyFullImage{url: $url, width: $width, height: $height, size: $size, mp4: $mp4, mp4Size: $mp4Size, webp: $webp, webpSize: $webpSize}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is GiphyFullImage &&
          runtimeType == other.runtimeType &&
          url == other.url &&
          width == other.width &&
          height == other.height &&
          size == other.size &&
          mp4 == other.mp4 &&
          mp4Size == other.mp4Size &&
          webp == other.webp &&
          webpSize == other.webpSize;

  @override
  int get hashCode =>
      url.hashCode ^
      width.hashCode ^
      height.hashCode ^
      size.hashCode ^
      mp4.hashCode ^
      mp4Size.hashCode ^
      webp.hashCode ^
      webpSize.hashCode;
}

class GiphyOriginalImage {
  final String url;
  final String width;
  final String height;
  final String size;
  final String frames;
  final String mp4;
  final String mp4Size;
  final String? webp;
  final String? webpSize;
  final String hash;

  GiphyOriginalImage({
    required this.url,
    required this.width,
    required this.height,
    required this.size,
    required this.frames,
    required this.mp4,
    required this.mp4Size,
    required this.webp,
    required this.webpSize,
    required this.hash,
  });

  factory GiphyOriginalImage.fromJson(Map<String, dynamic> json) {
    return GiphyOriginalImage(
        url: json['url'],
        width: json['width'],
        height: json['height'],
        size: json['size'],
        frames: json['frames'],
        mp4: json['mp4'],
        mp4Size: json['mp4_size'],
        webp: json['webp'],
        webpSize: json['webp_size'],
        hash: json['hash']);
  }

  Map<String, dynamic> toJson() {
    return <String, dynamic>{
      'url': url,
      'width': width,
      'height': height,
      'size': size,
      'frames': frames,
      'mp4': mp4,
      'mp4_size': mp4Size,
      'webp': webp,
      'webp_size': webpSize,
      'hash': hash
    };
  }

  @override
  String toString() {
    return 'GiphyOriginalImage{url: $url, width: $width, height: $height, size: $size, frames: $frames, mp4: $mp4, mp4Size: $mp4Size, webp: $webp, webpSize: $webpSize, hash: $hash}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is GiphyOriginalImage &&
          runtimeType == other.runtimeType &&
          url == other.url &&
          width == other.width &&
          height == other.height &&
          size == other.size &&
          frames == other.frames &&
          mp4 == other.mp4 &&
          mp4Size == other.mp4Size &&
          webp == other.webp &&
          webpSize == other.webpSize &&
          hash == other.hash;

  @override
  int get hashCode =>
      url.hashCode ^
      width.hashCode ^
      height.hashCode ^
      size.hashCode ^
      frames.hashCode ^
      mp4.hashCode ^
      mp4Size.hashCode ^
      webp.hashCode ^
      webpSize.hashCode ^
      hash.hashCode;
}

class GiphyStillImage {
  final String url;
  final String width;
  final String height;
  final String size;

  GiphyStillImage({
    required this.url,
    required this.width,
    required this.height,
    required this.size,
  });

  factory GiphyStillImage.fromJson(Map<String, dynamic> json) =>
      GiphyStillImage(
          url: json['url'],
          width: json['width'],
          height: json['height'],
          size: json['size'] ?? '');

  Map<String, dynamic> toJson() {
    return <String, dynamic>{
      'url': url,
      'width': width,
      'height': height,
      'size': size
    };
  }

  @override
  String toString() {
    return 'GiphyStillImage{url: $url, width: $width, height: $height, size: $size}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is GiphyStillImage &&
          runtimeType == other.runtimeType &&
          url == other.url &&
          width == other.width &&
          height == other.height &&
          size == other.size;

  @override
  int get hashCode =>
      url.hashCode ^ width.hashCode ^ height.hashCode ^ size.hashCode;
}

class GiphyDownsampledImage {
  final String url;
  final String width;
  final String height;
  final String size;
  final String? webp;
  final String? webpSize;

  GiphyDownsampledImage({
    required this.url,
    required this.width,
    required this.height,
    required this.size,
    required this.webp,
    required this.webpSize,
  });

  factory GiphyDownsampledImage.fromJson(Map<String, dynamic> json) {
    return GiphyDownsampledImage(
        url: json['url'],
        width: json['width'],
        height: json['height'],
        size: json['size'],
        webp: json['webp'],
        webpSize: json['webp_size']);
  }

  Map<String, dynamic> toJson() {
    return <String, dynamic>{
      'url': url,
      'width': width,
      'height': height,
      'size': size,
      'webp': webp,
      'webp_size': webpSize
    };
  }

  @override
  String toString() {
    return 'GiphyDownsampledImage{url: $url, width: $width, height: $height, size: $size, webp: $webp, webpSize: $webpSize}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is GiphyDownsampledImage &&
          runtimeType == other.runtimeType &&
          url == other.url &&
          width == other.width &&
          height == other.height &&
          size == other.size &&
          webp == other.webp &&
          webpSize == other.webpSize;

  @override
  int get hashCode =>
      url.hashCode ^
      width.hashCode ^
      height.hashCode ^
      size.hashCode ^
      webp.hashCode ^
      webpSize.hashCode;
}

class GiphyLoopingImage {
  final String mp4;
  final String mp4Size;

  GiphyLoopingImage({
    required this.mp4,
    required this.mp4Size,
  });

  factory GiphyLoopingImage.fromJson(Map<String, dynamic> json) =>
      GiphyLoopingImage(mp4: json['mp4'], mp4Size: json['mp4_size']);

  Map<String, dynamic> toJson() =>
      <String, dynamic>{'mp4': mp4, 'mp4_size': mp4Size};

  @override
  String toString() {
    return 'GiphyLoopingImage{mp4: $mp4, mp4Size: $mp4Size}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is GiphyLoopingImage &&
          runtimeType == other.runtimeType &&
          mp4 == other.mp4 &&
          mp4Size == other.mp4Size;

  @override
  int get hashCode => mp4.hashCode ^ mp4Size.hashCode;
}

class GiphyPreviewImage {
  final String width;
  final String height;
  final String mp4;
  final String mp4Size;

  GiphyPreviewImage({
    required this.width,
    required this.height,
    required this.mp4,
    required this.mp4Size,
  });

  factory GiphyPreviewImage.fromJson(Map<String, dynamic> json) {
    return GiphyPreviewImage(
      width: json['width'],
      height: json['height'],
      mp4: json['mp4'] ?? '',
      mp4Size: json['mp4_size'] ?? '',
    );
  }

  Map<String, dynamic> toJson() {
    return <String, dynamic>{
      'width': width,
      'height': height,
      'mp4': mp4,
      'mp4_size': mp4Size
    };
  }

  @override
  String toString() {
    return 'GiphyPreviewImage{width: $width, height: $height, mp4: $mp4, mp4Size: $mp4Size}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is GiphyPreviewImage &&
          runtimeType == other.runtimeType &&
          width == other.width &&
          height == other.height &&
          mp4 == other.mp4 &&
          mp4Size == other.mp4Size;

  @override
  int get hashCode =>
      width.hashCode ^ height.hashCode ^ mp4.hashCode ^ mp4Size.hashCode;
}

class GiphyDownsizedImage {
  final String url;
  final String width;
  final String height;
  final String size;

  GiphyDownsizedImage({
    required this.url,
    required this.width,
    required this.height,
    required this.size,
  });

  factory GiphyDownsizedImage.fromJson(Map<String, dynamic> json) {
    return GiphyDownsizedImage(
      url: json['url'],
      width: json['width'],
      height: json['height'],
      size: json['size'],
    );
  }

  Map<String, dynamic> toJson() {
    return <String, dynamic>{
      'url': url,
      'width': width,
      'height': height,
      'size': size
    };
  }

  @override
  String toString() {
    return 'GiphyDownsizedImage{url: $url, width: $width, height: $height, size: $size}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is GiphyDownsizedImage &&
          runtimeType == other.runtimeType &&
          url == other.url &&
          width == other.width &&
          height == other.height &&
          size == other.size;

  @override
  int get hashCode =>
      url.hashCode ^ width.hashCode ^ height.hashCode ^ size.hashCode;
}

class GiphyWebPImage {
  final String url;
  final String width;
  final String height;
  final String size;

  GiphyWebPImage({
    required this.url,
    required this.width,
    required this.height,
    required this.size,
  });

  factory GiphyWebPImage.fromJson(Map<String, dynamic> json) {
    return GiphyWebPImage(
      url: json['url'],
      width: json['width'],
      height: json['height'],
      size: json['size'],
    );
  }

  Map<String, dynamic> toJson() {
    return <String, dynamic>{
      'url': url,
      'width': width,
      'height': height,
      'size': size
    };
  }

  @override
  String toString() {
    return 'GiphyWebPImage{url: $url, width: $width, height: $height, size: $size}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is GiphyWebPImage &&
          runtimeType == other.runtimeType &&
          url == other.url &&
          width == other.width &&
          height == other.height &&
          size == other.size;

  @override
  int get hashCode =>
      url.hashCode ^ width.hashCode ^ height.hashCode ^ size.hashCode;
}
